summaryrefslogtreecommitdiffstats
path: root/kparts/browserrun.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kparts/browserrun.cpp')
-rw-r--r--kparts/browserrun.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kparts/browserrun.cpp b/kparts/browserrun.cpp
index e77f1f87e..4d23d6300 100644
--- a/kparts/browserrun.cpp
+++ b/kparts/browserrun.cpp
@@ -71,7 +71,7 @@ void BrowserRun::init()
{
if ( d->m_bHideErrorDialog )
{
- // ### KRun doesn't call a virtual method when it tqfinds out that the URL
+ // ### KRun doesn't call a virtual method when it finds out that the URL
// is either malformed, or points to a non-existing local file...
// So we need to reimplement some of the checks, to handle m_bHideErrorDialog
if ( !m_strURL.isValid() ) {
@@ -128,7 +128,7 @@ void BrowserRun::scanFile()
}
// Set the PropagateHttpHeader meta-data if it has not already been set...
- if (!m_args.metaData().tqcontains("PropagateHttpHeader"))
+ if (!m_args.metaData().contains("PropagateHttpHeader"))
m_args.metaData().insert("PropagateHttpHeader", "TRUE");
}
@@ -209,7 +209,7 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const TQString&
!m_strURL.isLocalFile() )
{
if ( isTextExecutable(mimeType) )
- mimeType = TQString::tqfromLatin1("text/plain"); // view, don't execute
+ mimeType = TQString::fromLatin1("text/plain"); // view, don't execute
kdDebug(1000) << "BrowserRun: ask for saving" << endl;
KService::Ptr offer = KServiceTypeProfile::preferredService(mimeType, "Application");
// ... -> ask whether to save
@@ -236,7 +236,7 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const TQString&
m_sMimeType = mimeType;
TQString extension;
TQString fileName = m_suggestedFilename.isEmpty() ? m_strURL.fileName() : m_suggestedFilename;
- int extensionPos = fileName.tqfindRev( '.' );
+ int extensionPos = fileName.findRev( '.' );
if ( extensionPos != -1 )
extension = fileName.mid( extensionPos ); // keep the '.'
KTempFile tempFile( TQString::null, extension );
@@ -313,7 +313,7 @@ BrowserRun::AskSaveResult BrowserRun::askSave( const KURL & url, KService::Ptr o
int choice = KMessageBox::questionYesNoCancel(
0L, question, url.host(),
KStdGuiItem::saveAs(), openText,
- TQString::tqfromLatin1("askSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
+ TQString::fromLatin1("askSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
return choice == KMessageBox::Yes ? Save : ( choice == KMessageBox::No ? Open : Cancel );
// SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
@@ -341,8 +341,8 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KURL & url, const TQ
mime->is( "text/xml" ) ||
mime->is( "inode/directory" ) ||
mimeType.startsWith( "image" ) ||
- mime->is( "multipart/x-mixed-tqreplace" ) ||
- mime->is( "multipart/tqreplace" ) ||
+ mime->is( "multipart/x-mixed-replace" ) ||
+ mime->is( "multipart/replace" ) ||
mimeType.startsWith( "print" ) ) )
return Open;
@@ -351,7 +351,7 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KURL & url, const TQ
int choice = KMessageBox::questionYesNoCancel(
0L, question, url.host(),
KStdGuiItem::saveAs(), KGuiItem( i18n( "&Open" ), "fileopen"),
- TQString::tqfromLatin1("askEmbedOrSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
+ TQString::fromLatin1("askEmbedOrSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
return choice == KMessageBox::Yes ? Save : ( choice == KMessageBox::No ? Open : Cancel );
// SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
}
@@ -372,7 +372,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
TQWidget* window )
{
// DownloadManager <-> konqueror integration
// tqfind if the integration is enabled
// the empty key means no integration
// only use the downloadmanager for non-local urls
if ( !url.isLocalFile() )
@@ -382,7 +382,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
TQString downloadManger = cfg.readPathEntry("DownloadManager");
if (!downloadManger.isEmpty())
{
// then tqfind the download manager location
kdDebug(1000) << "Using: "<<downloadManger <<" as Download Manager" <<endl;
TQString cmd=KStandardDirs::findExe(downloadManger);
if (cmd.isEmpty())
@@ -372,7 +372,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
{
// DownloadManager <-> konqueror integration
- // tqfind if the integration is enabled
+ // find if the integration is enabled
// the empty key means no integration
// only use the downloadmanager for non-local urls
@@ -382,7 +382,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
if (!downloadManger.isEmpty())
{
- // then tqfind the download manager location
+ // then find the download manager location
kdDebug(1000) << "Using: "<<downloadManger <<" as Download Manager" <<endl;
TQString cmd=KStandardDirs::findExe(downloadManger);